code stringlengths 4 1.01M | language stringclasses 2
values |
|---|---|
/*
* Webpack development server configuration
*
* This file is set up for serving the webpack-dev-server, which will watch for changes and recompile as required if
* the subfolder /webpack-dev-server/ is visited. Visiting the root will not automatically reload.
*/
'use strict';
import webpack from 'webpack';
impor... | Java |
// This code will add an event listener to each anchor of the topbar after being dynamically replaced by "interchange"
$("body").on("click", function(event){
// If the active element is one of the topbar's links continues
if($(event.target).hasClass("topbarLink")) {
// The parent li element of the current acti... | Java |
const elixir = require('laravel-elixir');
elixir((mix) => {
// Mix all Sass files into one
mix.sass('app.scss');
// Mix all vendor scripts together
mix.scripts(
[
'jquery/dist/jquery.min.js',
'bootstrap-sass/assets/javascripts/bootstrap.min.js',
'bootstrap-s... | Java |
require 'spec_helper'
describe User do
context 'fields' do
it { should have_field(:email).of_type(String)}
it { should have_field(:encrypted_password).of_type(String)}
it { should have_field(:roles).of_type(Array)}
end
context 'Mass assignment' do
it { should allow_mass_assignment_of(:email)... | Java |
import {Map} from 'immutable';
export function getInteractiveLayerIds(mapStyle) {
let interactiveLayerIds = [];
if (Map.isMap(mapStyle) && mapStyle.has('layers')) {
interactiveLayerIds = mapStyle.get('layers')
.filter(l => l.get('interactive'))
.map(l => l.get('id'))
.toJS();
} else if (Ar... | Java |
<!doctype html>
<html>
<head>
</head>
<body>
<h1>Milestones - Codenautas</h1>
<div id=milestones></div>
<script src=milestones.js></script>
</body>
</html>
| Java |
/*
* Created on 24/02/2014
*
*/
package net.rlviana.pricegrabber.model.entity.common;
import net.rlviana.pricegrabber.context.JPAPersistenceContext;
import net.rlviana.pricegrabber.model.entity.AbstractReadOnlyEntityTest;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.slf4j.Logger;
import org.sl... | Java |
package machinelearningservices
// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.
//
// Code generated by Microsoft (R) AutoRest Code Generator.
// Changes may cause incorrect behavior and will be lost if the cod... | Java |
#include "utfgrid_encode.h"
#include <unordered_map>
#include <glog/logging.h>
#include <jsoncpp/json/value.h>
#include <mapnik/unicode.hpp>
struct value_to_json_visitor {
Json::Value operator() (const mapnik::value_null& val) {return Json::Value();}
Json::Value operator() (const mapnik::value_bool& val) {re... | Java |
package me.moodcat.api;
import java.util.Arrays;
import java.util.List;
import java.util.Locale;
import java.util.stream.Collectors;
import lombok.Getter;
import me.moodcat.database.embeddables.VAVector;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnore;
/**
* A... | Java |
<!-- CONTAINER BODY -->
<div class="panel-group" >
<div class="panel panel-default" >
<div class="panel-body">
<h4>Filmovi</h4>
<!-- Film List -->
<hr/>
<?php foreach($list as $row): ?>
<div class="row text-left">
... | Java |
<?php
$lang = array(
'addons' => 'Add-ons',
'accessories' => 'Accessories',
'modules' => 'Modules',
'extensions' => 'Extensions',
'plugins' => 'Plugins',
'accessory' => 'Accessory',
'module' => 'Module',
'extension' => 'Extension',
'rte_tool' => 'Rich Text Editor... | Java |
# ux - Micro Xylph
ux は軽量でシンプルな動作を目標としたソフトウェアシンセサイザです。C# で作られており、Mono 上でも動作します。
## 概要
ux は [Xylph](http://www.johokagekkan.go.jp/2011/u-20/xylph.html) (シルフ) の後継として開発されています。Xylph の開発で得られた最低限必要な機能を絞り、なおかつ Xylph よりも軽快に動作するよう設計されています。C# で記述しつつ、極力高速な動作が目標です。
ux は モノフォニック、複数パート、ポルタメント、ビブラートなどの機能を持ち、音源として矩形波、16 段三角波、ユーザ波... | Java |
---
title: L.esri.Layers.TiledMapLayer
layout: documentation.hbs
---
# {{page.data.title}}
Inherits from [`L.TileLayer`](http://leafletjs.com/reference.html#tilelayer)
Access tiles from ArcGIS Online and ArcGIS Server as well as visualize and identify features.
Is you have Feature Services published in ArcGIS Onlin... | Java |
import time
import multiprocessing
from flask import Flask
app = Flask(__name__)
backProc = None
def testFun():
print('Starting')
while True:
time.sleep(3)
print('looping')
time.sleep(3)
print('3 Seconds Later')
@app.route('/')
def root():
return 'Started a background pr... | Java |
package forscher.nocket.page.gen.ajax;
import gengui.annotations.Eager;
import java.io.Serializable;
public class AjaxTargetUpdateTestInner implements Serializable {
private String feld1;
private String feld2;
public String getEagerFeld1() {
return feld1;
}
@Eager
public void setEa... | Java |
---
layout: single
title: Vue와 Firebase로 모던웹사이트 만들기 43 파이어베이스 함수에서 권한 확인하기
category: vf
tag: [vue,node,express,vuetify,firebase,vscode]
comments: true
sidebar:
nav: "vf"
toc: true
toc_label: "목차"
toc_icon: "list"
---
파이어베이스 함수(functions)에서 토큰을 확인하고 풀어헤친 토큰정보(claims)로 권한에 따른 결과를 보냅니다.
# 영상
{% include video id="x6_Q... | Java |
'''
Created by auto_sdk on 2014-12-17 17:22:51
'''
from top.api.base import RestApi
class SubusersGetRequest(RestApi):
def __init__(self,domain='gw.api.taobao.com',port=80):
RestApi.__init__(self,domain, port)
self.user_nick = None
def getapiname(self):
return 'taobao.subusers.get'
| Java |
var textDivTopIndex = -1;
/**
* Creates a div that contains a textfiled, a plus and a minus button
* @param {String | undefined} textContent string to be added to the given new textField as value
* @returns new div
*/
function createTextDiv( textContent ) {
textDivTopIndex++;
var newTextDiv = document.create... | Java |
#pragma once
#include "ofMain.h"
#include "ofxOsc.h"
#include "VHPtriggerArea.h"
#include "ofxXmlSettings.h"
class ofApp : public ofBaseApp{
public:
void setup();
void update();
void draw();
void keyPressed(int key);
void keyReleased(int key);
void mouseMoved(int x, int y );
void mouseDragged(int x, ... | Java |
using System.Collections.Generic;
using System.Text.Json.Serialization;
namespace MtgApiManager.Lib.Dto.Set
{
internal class RootSetListDto : IMtgResponse
{
[JsonPropertyName("sets")]
public List<SetDto> Sets { get; set; }
}
} | Java |
---
tags: perl
layout: post
title: "Chris, meet testing"
---
<p>I need to start writing software as if it will be
released to lots of people tomorrow :) Interestingly, the
potential (up to 90% I'd say) release of OpenInteract has
coincided with my first reading of Kent Beck's book <a
href="http://www1.fatbrain.c... | Java |
# frozen_string_literal: true
RSpec.describe Faraday::Response::RaiseError do
let(:conn) do
Faraday.new do |b|
b.response :raise_error
b.adapter :test do |stub|
stub.get('ok') { [200, { 'Content-Type' => 'text/html' }, '<body></body>'] }
stub.get('bad-request') { [400, { 'X-Reason' =>... | Java |
class CreateBudgetsUsers < ActiveRecord::Migration
def change
create_table :budgets_users do |t|
t.integer :user_id
t.integer :budget_id
t.timestamps
end
end
end
| Java |
package org.anodyneos.xp.tagext;
import javax.servlet.jsp.el.ELException;
import org.anodyneos.xp.XpContext;
import org.anodyneos.xp.XpException;
import org.anodyneos.xp.XpOutput;
import org.xml.sax.SAXException;
/**
* @author jvas
*/
public interface XpTag {
void doTag(XpOutput out) throws XpException, ELEx... | Java |
'use strict';
/**
* Stripe library
*
* @module core/lib/c_l_stripe
* @license MIT
* @copyright 2016 Chris Turnbull <https://github.com/christurnbull>
*/
module.exports = function(app, db, lib) {
return {
/**
* Donate
*/
donate: function(inObj, cb) {
var number, expiry, cvc, currency;
... | Java |
using System;
using System.Threading.Tasks;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Logging;
using Xunit;
namespace MR.AspNetCore.Jobs.Server
{
public class InfiniteRetryProcessorTest
{
[Fact]
public async Task Process_ThrowingProcessingCanceledException_Returns()
{
// Arr... | Java |
// This file auto generated by plugin for ida pro. Generated code only for x64. Please, dont change manually
#pragma once
#include <common/common.h>
START_ATF_NAMESPACE
struct _notify_raceboss_cry_msg_request_zocl
{
char wszCryMsg[10][65];
};
END_ATF_NAMESPACE
| Java |
/*
artifact generator: C:\My\wizzi\v5\node_modules\wizzi-js\lib\artifacts\js\module\gen\main.js
primary source IttfDocument: c:\my\wizzi\v5\plugins\wizzi-core\src\ittf\root\legacy.js.ittf
*/
'use strict';
module.exports = require('wizzi-legacy-v4');
| Java |
---
title: "Puppet"
description: "Deregister Sensu clients from the client registry if they no
longer have an associated Puppet node."
version: 1.0
weight: 12
---
**ENTERPRISE: Built-in integrations are available for [Sensu Enterprise][1]
users only.**
# Puppet Integration
- [Overview](#overview)
- [Configuration]... | Java |
#!/bin/env node
'use strict';
var winston = require('winston'),
path = require('path'),
mcapi = require('mailchimp-api'),
Parser = require('./lib/parser'),
ApiWrapper = require('./lib/api-wrapper');
var date = new Date();
date = date.toJSON().replace(/(-|:)/g, '.');
winston.remove(winston.transports.Con... | Java |
+++
hook = "A list of the best podcasts that I'm listening to this year."
published_at = 2016-08-28T01:13:48Z
title = "Podcasts 2016"
+++
After moving to the big city, I've spent a lot more time on foot over the past
few years. I eventually picked up another habit that pairs with walking
perfectly: podcasts.
As of 20... | Java |
module.exports = {
normalizeEntityName: function() {},
afterInstall: function() {
this.addBowerPackageToProject('jsoneditor');
}
};
| Java |
# Wiper
Wiper allows you to recursively delete specified folders.
Say that you want to delete all 'obj' folders in a certain root folder.
Type in 'obj' as the folder name to delete and select the root folder.
Perform a dry run to list all folders that will be affected.
Hit the delete button and you're done!
| Java |
import AMD from '../../amd/src/amd.e6';
import Core from '../../core/src/core.e6';
import Event from '../../event/src/event.e6';
import Detect from '../../detect/src/detect.e6';
import Module from '../../modules/src/base.es6';
import ModulesApi from '../../modules/src/api.e6';
window.Moff = new Core();
window.Moff.amd... | Java |
<html><body>
<h4>Windows 10 x64 (19042.610)</h4><br>
<h2>_PNP_DEVICE_DELETE_TYPE</h2>
<font face="arial"> QueryRemoveDevice = 0n0<br>
CancelRemoveDevice = 0n1<br>
RemoveDevice = 0n2<br>
SurpriseRemoveDevice = 0n3<br>
EjectDevice = 0n4<br>
RemoveFailedDevice = 0n5<br>
RemoveUnstartedFailedDe... | Java |
---
archive: tag
layout: archive
permalink: /tag/Simpsons/
tag: Simpsons
title: Archive for Simpsons
---
| Java |
# == Schema Information
#
# Table name: templates
#
# id :integer not null, primary key
# name :string
# image :string
# description :text
# created_at :datetime not null
# updated_at :datetime not null
#
require 'rails_helper'
RSpec.describe Template, type: :mod... | Java |
namespace RapidFTP.Chilkat.Tests.Utilities
{
using System.Diagnostics;
using RapidFTP.Models;
using RapidFTP.Utilities;
using Xunit;
using Xunit.Extensions;
public class UnixPathTest
{
[InlineData("/lv1", 1)]
[InlineData("/lv1/lv2", 2)]
[InlineData("/lv1/lv2/", 2)... | Java |
package org.real2space.neumann.evaris.core.structure;
/**
* Project Neumann
*
* @author RealTwo-Space
* @version 0
*
* created 2016/11/01
* added "extends Ring<F>" 2016/11/9
*/
public interface Field<F> extends Ring<F> {
/*
* Multiply this member by an inverse of "other".
*/
public void d... | Java |
# coding: utf-8
import unittest
from config_reader import ConfigReader
class TestConfigReader(unittest.TestCase):
def setUp(self):
self.config = ConfigReader("""
<root>
<person>
<name>山田</name>
<age>15</age>
</person>
... | Java |
# project/server/tests/test_user.py
import datetime
import unittest
from flask_login import current_user
from base import BaseTestCase
from project.server import bcrypt
from project.server.models import User
from project.server.user.forms import LoginForm
class TestUserBlueprint(BaseTestCase):
def test_correc... | Java |
inside = lambda x, y: 4*x*x+y*y <= 100
def coll(sx, sy, dx, dy):
m = 0
for p in range(32):
m2 = m + 2**(-p)
if inside(sx + dx * m2, sy + dy * m2): m = m2
return (sx + dx*m, sy + dy*m)
def norm(x, y):
l = (x*x + y*y)**0.5
return (x/l, y/l)
sx, sy = 0, 10.1
dx, dy = 1.4, -19.7
for ... | Java |
# Git Back Control of Your Code
## A Simple and Straightforward Workflow for Working with Git and Github
Becoming a better developer is about finding the process and workflow that works best for you and the rest of the team. I believe that version control is something all developers should use. Specifically, I think ... | Java |
//
// main.c
// demo14
//
// Created by weichen on 15/1/9.
// Copyright (c) 2015年 weichen. All rights reserved.
//
#include <stdio.h>
int main() {
// 求输入的数的平均数,并输出大于平均数的数字
int x = 0; //输入的数
double num = 0; //总和(这个定义为double, 因为计算结果可能出现浮点数)
int count = 0; //个数
double per; //平均数(结果... | Java |
---
layout: default
description: "你来到了没有知识的荒原 🙊"
header-img: "img/404-bg.jpg"
permalink: /404.html
---
<!-- Page Header -->
<header class="intro-header" style="background-image: url('{{ site.baseurl }}/{% if page.header-img %}{{ page.header-img }}{% else %}{{ site.header-img }}{% endif %}')">
<div class="... | Java |
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>Plugwise implementation: energykit.plugwise —... | Java |
/**
* Module dependencies
*/
const express = require('express');
const cluster = require('cluster');
const numCPUs = require('os').cpus().length;
const compression = require('compression');
const helmet = require('helmet');
const hpp = require('hpp');
const config = require('./config');
const api = require('./api');
... | Java |
class UsersController < ApplicationController
def new
end
def create
user = User.new(
email: params[:email],
password: params[:password],
password_confirmation: params[:password_confirmation])
if user.save
session[:user_id] = user.id
... | Java |
#!/bin/sh
set -e
echo "mkdir -p ${CONFIGURATION_BUILD_DIR}/${FRAMEWORKS_FOLDER_PATH}"
mkdir -p "${CONFIGURATION_BUILD_DIR}/${FRAMEWORKS_FOLDER_PATH}"
SWIFT_STDLIB_PATH="${DT_TOOLCHAIN_DIR}/usr/lib/swift/${PLATFORM_NAME}"
install_framework()
{
if [ -r "${BUILT_PRODUCTS_DIR}/$1" ]; then
local source="${BUILT_PRO... | Java |
<div id="top" class="container-fluid">
<div class="navbar navbar-default navbar-fixed-top" style="border-bottom: 1px solid #666 !important;">
<h1 class="homeTitle pull-left">Books Library</h1>
<a href="#/#/top" title="Top" class="btn btn-primary page-scroll home glyphicon glyphicon-plane pull-right"></a>
</div>
... | Java |
#include <vector>
#include <iostream>
struct point
{
double x;
double y;
};
int main()
{
// Generate a lot of uniformly distributed 2d points in the range -1,-1 to +1,+1.
enum { numXSamples = 10000 };
enum { numYSamples = 10000 };
std::vector<point> points;
points.reserve(numXSamples * numYSamples);
for(int x... | Java |
#!/usr/bin/env bash
# Copyright (c) 2016 Ericsson AB
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, me... | Java |
//
// RBViewController.h
// Pods
//
// Created by Param Aggarwal on 01/02/15.
//
//
#import <UIKit/UIKit.h>
#import "RBViewControllerModel.h"
@interface RBViewController : UIViewController
+ (instancetype)create:(RBViewControllerModel *)model;
- (void)update:(RBViewControllerModel *)model;
- (void)updateChildren:... | Java |
<p>
Disponemos de una amplia gama de piensos fisiológicos y de prescripción veterinaria; nuestras auxiliares nutricionistas le asesorarán sobre cualquier aspecto relacionado con la alimentación de su mascota.
</p>
<p>
Contamos con sección especializada en alimentación de animales exóticos.
</p>
<p>
Asimismo, podrá e... | Java |
class CreateVersions < ActiveRecord::Migration
def change
create_table :versions do |t|
t.string :item_type, :null => false
t.integer :item_id, :null => false
t.string :event, :null => false
t.string :whodunnit
t.text :object
t.string :locale
t.datetime... | Java |
<!DOCTYPE html>
<html>
<head>
<title>Piframe</title>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
<meta name="robots" content="noindex"/>
<meta name="viewport" content="width=device-width"/>
<script type="text/javascript" src="lib/jquery/jquery-1.12.0.min.js"></script>
<link rel="stylesh... | Java |
using System;
using System.Drawing;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Forms;
using System.Windows.Input;
using MahApps.Metro.Controls;
using NHotkey;
using NHotkey.Wpf;
using QuickHelper.ViewModels;
using QuickHelper.Windows;
using Application = System.Windows.Application;
using... | Java |
package com.comandante.creeper.command.commands;
import com.comandante.creeper.common.FriendlyTime;
import org.junit.Test;
public class FriendlyTimeTest {
@Test
public void testFriendlyParsing() throws Exception {
FriendlyTime friendlyTime = new FriendlyTime(400);
System.out.println("Frien... | Java |
using System.Reflection;
using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
// General Information about an assembly is controlled through the following
// set of attributes. Change these attribute values to modify the information
// associated with an assembly.
[assembly: AssemblyTitle("Tr... | Java |
# React Drop-down Time Picker
Time picker for ReactJS based on the [Cozi Calendar](https://www.cozi.com/calendar) time picker. [See the demo](https://dpalma.github.io/react-dropdown-timepicker/).
[](https://travis-ci.org/dpalma/re... | Java |
package fs.command;
import fs.App;
import fs.Disk;
import fs.util.FileUtils;
import java.util.Arrays;
/**
*
* @author José Andrés García Sáenz <jags9415@gmail.com>
*/
public class CreateFileCommand extends Command {
public final static String COMMAND = "mkfile";
@Override
public void execute(Str... | Java |
import { A, O } from 'b-o-a';
import { State } from '../types/state';
import currentPage$ from '../props/current-page';
import signIn$ from '../props/sign-in';
import spots$ from '../props/spots';
import spotForm$ from '../props/spot-form';
import stampRallies$ from '../props/stamp-rallies';
import stampRally$ from '... | Java |
// Copyright (c) 2009-2010 Satoshi Nakamoto
// Copyright (c) 2009-2012 The Bitcoin developers
// Copyright (c) 2011-2012 Litecoin Developers
// Copyright (c) 2013-2013 Bluecoin Developers
// Distributed under the MIT/X11 software license, see the accompanying
// file COPYING or http://www.opensource.o... | Java |
/*
组件列表 外在肌肤,水嫩丝滑
生成时间:Sat Dec 17 2016 破门狂人R2-D2为您服务!
*/
.list{
}
.lib-list-item{
display: block;
color: #393939;
border: 1px solid #ddd;
border-radius: 5px;
text-align: center;
line-height: 2.2;
}
.lib-list-item:hover{
box-shadow:0px 2px 10px #c9c9c9;
color: #f6eaa2;
text-sha... | Java |
<!DOCTYPE html>
<!--[if lt IE 7 ]><html class="ie ie6" lang="en"> <![endif]-->
<!--[if IE 7 ]><html class="ie ie7" lang="en"> <![endif]-->
<!--[if IE 8 ]><html class="ie ie8" lang="en"> <![endif]-->
<!--[if (gte IE 9)|!(IE)]><!-->
<html lang="en" xmlns="http://www.w3.org/1999/html"> <!--<![endif]-->
<head>
<!-- Basic... | Java |
'use strict';
/*
* * angular-socialshare v0.0.2
* * ♡ CopyHeart 2014 by Dayanand Prabhu http://djds4rce.github.io
* * Copying is an act of love. Please copy.
* */
angular.module('djds4rce.angular-socialshare', [])
.factory('$FB', ['$window', function($window) {
return {
init: function(fbId) {
... | Java |
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Xml;
using System.Xml.Linq;
using System.Globalization;
namespace DevTreks.Extensions
{
/// <summary>
///Purpose: Serialize and deserialize a food nutrition cost object.
/// This calculator is u... | Java |
angular.module('myApp.toDoController', []).
controller('ToDoCtrl', ['$scope', '$state', '$http', '$route', function ($scope, $state, $http, $route) {
$scope.$state = $state;
$scope.addToDo = function() {
// Just in case...
if ($scope.toDoList.length > 50) {
alert("Exceeded to-do limit!!!");
retu... | Java |
// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License.
package com.azure.data.cosmos.internal.query;
import com.azure.data.cosmos.BadRequestException;
import com.azure.data.cosmos.BridgeInternal;
import com.azure.data.cosmos.CommonsBridgeInternal;
import com.azure.data.cosmos.i... | Java |
<!DOCTYPE html>
<html lang="en">
<head>
<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1">
<title>Coq bench</title>
<link rel="shortcut icon" type="image/png" href="../../../../../favicon.png" />
<link href="../../../../../bootstrap.min.css" rel="stylesheet... | Java |
import sys
MAX_NUM_STORED_LINES = 200
MAX_NUM_LINES = 10
LINEWIDTH = 80
class CmdText(object):
"""
Represents a command line text device. Text is split into lines
corresponding to the linewidth of the device.
"""
def __init__(self):
"""
Construct empty object.
"""
s... | Java |
<?php
require_once (__DIR__ . '/../lib/bootstrap.php');
require_once (__DIR__ . '/lib/TestListener.php');
use PHPUnit\Framework\TestCase;
use Selenide\By, Selenide\Condition, Selenide\Selenide;
class ListenerTest extends TestCase
{
/**
* @var Selenide
*/
protected static $wd = null;
protected ... | Java |
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using FlatRedBall;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework;
namespace Anfloga.Rendering
{
public class BloomRenderer : IEffectsRenderer
{
public int Height { get; set; }
public i... | Java |
#[macro_export]
macro_rules! punctuator {
($lexer: ident, $p: ident) => ({
$lexer.iter.next();
Ok(Token::Punctuator(Punctuator::$p, $lexer.lo, $lexer.lo + 1))
})
}
// Advance iter and hi position if pattern match
#[macro_export]
macro_rules! take {
($lexer: ident, $($p: pat)|*) => (
match $le... | Java |
//
// This source file is part of appleseed.
// Visit http://appleseedhq.net/ for additional information and resources.
//
// This software is released under the MIT license.
//
// Copyright (c) 2010-2013 Francois Beaune, Jupiter Jazz Limited
// Copyright (c) 2014-2015 Francois Beaune, The appleseedhq Organization
//
... | Java |
/*
* Copyright (c) 2010, ETH Zurich.
* All rights reserved.
*
* INTERFACE NAME: mem
* INTEFACE FILE: ../if/mem.if
* INTERFACE DESCRIPTION: Memory allocation RPC interface
*
* This file is distributed under the terms in the attached LICENSE
* file. If you do not find this file, copies can be found by
* writi... | Java |
/* from optimizations/bfs/topology-atomic.cu */
#define BFS_VARIANT "topology-atomic"
#define WORKPERTHREAD 1
#define VERTICALWORKPERTHREAD 12 // max value, see relax.
#define BLKSIZE 1024
#define BANKSIZE BLKSIZE
__global__
void initialize(foru *dist, unsigned int *nv) {
unsigned int ii = blockIdx.x * blockDim.x +... | Java |
<!DOCTYPE html>
<html lang="en">
<head>
<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1.0">
<meta name="generator" content="rustdoc">
<meta name="description" content="API documentation for the Rust `benchmark` fn in crate `test`.">
<meta name="keywords" con... | Java |
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<!-- NewPage -->
<html lang="en">
<head>
<!-- Generated by javadoc (1.8.0_60) on Fri Dec 11 10:08:00 MST 2015 -->
<title>ca.ualberta.cs.xpertsapp.UITests.FriendTests</title>
<meta name="date" content="2015-12-11">
<li... | Java |
#include <stdio.h>
#include <stdint.h>
#include <ibcrypt/chacha.h>
#include <ibcrypt/rand.h>
#include <ibcrypt/sha256.h>
#include <ibcrypt/zfree.h>
#include <libibur/util.h>
#include <libibur/endian.h>
#include "datafile.h"
#include "../util/log.h"
int write_datafile(char *path, void *arg, void *data, struct forma... | Java |
# Acknowledgements
This application makes use of the following third party libraries:
## GreenAR
Copyright (c) 2017 Daniel Grenier <seanalair@gmail.com>
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the So... | Java |
import CommuniqueApp from './communique-app';
CommuniqueApp.open();
| Java |
using System.Collections.Generic;
using System.IO;
using Reinforced.Typings.Fluent;
using Xunit;
namespace Reinforced.Typings.Tests.SpecificCases
{
public partial class SpecificTestCases
{
[Fact]
public void ReferencesPart6ByDanielWest()
{
/**
* Specific test ca... | Java |
package com.avsystem.scex.util.function;
import org.apache.commons.codec.digest.HmacAlgorithms;
import org.apache.commons.codec.digest.HmacUtils;
import org.apache.commons.lang3.RandomStringUtils;
import org.apache.commons.lang3.StringUtils;
import java.util.Collection;
public class StringUtilImpl implements StringU... | Java |
require 'minitest_helper'
require 'mocha/setup'
module Sidekiq
module Statistic
describe 'Middleware' do
def to_number(i)
i.match('\.').nil? ? Integer(i) : Float(i) rescue i.to_s
end
before { Sidekiq.redis(&:flushdb) }
let(:date){ Time.now.utc.to_date }
let(:actual) do
... | Java |
PHP with classes and PhpUnit | Java |
#include <QtGlobal>
// Automatically generated by extract_strings.py
#ifdef __GNUC__
#define UNUSED __attribute__((unused))
#else
#define UNUSED
#endif
static const char UNUSED *bitcoin_strings[] = {
QT_TRANSLATE_NOOP("bitcoin-core", ""
"%s, you must set a rpcpassword in the configuration file:\n"
"%s\n"
"It is recomme... | Java |
<!doctype html>
<!--[if IE 9 ]><html class="ie9" lang="en"><![endif]-->
<!--[if (gt IE 9)|!(IE)]><!--><html lang="en"><!--<![endif]-->
<head>
<title>Flatastic - Checkout</title>
<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no">
<!... | Java |
package work.notech.poker.room;
import work.notech.poker.logic.Cards;
import java.util.List;
public class GameRoom {
private Integer roomIds;
private List<Integer> clientIds;
private Cards cards;
public Integer getRoomIds() {
return roomIds;
}
public void setRoomIds(Integer roomIds)... | Java |
---
title: 22 Points to Go
author: rami
layout: lifestream
categories: [Lifestream]
tags: [jeddah, saudi-arabia, juve, path]
image: 22-points-to-go.jpg
---
10 games & 22 points to go. With games against the 20th place ,19,15,14,13,11. #Juve CC:@juventiknows.
{% include image.html url="/assets/images/content/lifest... | Java |
// Take well-formed json from a sensu check result a context rich html document to be mail to
// one or more addresses.
//
// LICENSE:
// Copyright 2016 Yieldbot. <devops@yieldbot.com>
// Released under the MIT License; see LICENSE
// for details.
package main
import (
"bytes"
"fmt"
"github.com/codegangsta/c... | Java |
module.exports = [
'babel-polyfill',
'react',
'react-redux',
'react-router',
'react-dom',
'redux',
'redux-thunk',
'seamless-immutable',
'react-router-redux',
'history',
'lodash',
'styled-components',
'prop-types',
];
| Java |
<?php
/*
* This file is part of the Symfony package.
*
* (c) Fabien Potencier <fabien@symfony.com>
*
* For the full copyright and license information, please view the LICENSE
* file that was distributed with this source code.
*/
namespace Symfony\Component\HttpKernel\DataCollector;
use Symfony\Component\HttpF... | Java |
package com.sunilson.pro4.activities;
import android.app.DatePickerDialog;
import android.app.TimePickerDialog;
import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.v7.widget.Toolbar;
import android.view.View;
import android.widget.CompoundButton;
i... | Java |
{% load staticfiles %}
<!DOCTYPE html>
<html>
<head>
<title>
{% block title %}Default Title{% endblock %}
</title>
{% block stylesheets %}
<link href="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/css/bootstrap.min.css" rel="stylesheet">
<link rel="stylesheet"... | Java |
import nextConnect from 'next-connect'
import auth from '../../middleware/auth'
import { deleteUser, updateUserByUsername } from '../../lib/db'
const handler = nextConnect()
handler
.use(auth)
.get((req, res) => {
// You do not generally want to return the whole user object
// because it may contain sensi... | Java |
<?php
namespace Plumber\Tests\Deployer;
use Plumber\Server\Server;
class NoRsyncDeployerTest extends \PHPUnit_Framework_TestCase
{
public function testRsyncDeployWithNotExistingRsyncExcludeFile()
{
$server = new Server( 'localhost', 'julien', '/var/www/', 22 );
$deployer = new \Plumber\Deployer\NoRsyncDeploye... | Java |
!function(a){var b,c,d;return a.localStorage||(c={setItem:function(a,b,c){var d,e;return null==c&&(c=!1),d=c?-1:30,e=new Date,e.setDate(e.getDate()+d),document.cookie=""+a+"="+escape(b)+"; expires="+e.toUTCString()},getItem:function(a){return document.cookie.indexOf(-1!==""+a+"=")?unescape(document.cookie.split(""+a+"=... | Java |
import { injectReducer } from 'STORE/reducers'
export default store => ({
path : 'checkHistoryList.html',
getComponent(nextState, cb) {
require.ensure([], (require) => {
const CheckHistoryList = require('VIEW/CheckHistoryList').default
const reducer = require('REDUCER/checkHistoryList').default
... | Java |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.